@@ -21,8 +21,9 @@ import requests
 from .get_token import get_token
 
 # get_wdpa()
-def get_wdpa(iso3, output_dir="."):
 
+
+def get_wdpa(iso3, output_dir="."):
     """This function downloads protected areas for one country using the
     WDPA API. Protected areas defined by a point are not
     considered. The shapefile is written on the hard drive (in the
@@ -47,7 +48,7 @@ def get_wdpa(iso3, output_dir="."):
     response = json.loads(response.text)  # Equivalent to response.json()
 
     pas_count = response["country"]["pas_count"]
-    pages = list(range(np.int(np.ceil(pas_count / 50.0))))
+    pages = list(range(int(np.ceil(pas_count / 50.0))))
 
     if pas_count is not None:
 
@@ -64,10 +65,14 @@ def get_wdpa(iso3, output_dir="."):
         # Add attributes
         layer.CreateField(ogr.FieldDefn("wdpa_id", ogr.OFTInteger))
         layer.CreateField(ogr.FieldDefn("pa_name", ogr.OFTString))
+        layer.CreateField(ogr.FieldDefn("orig_name", ogr.OFTString))
         layer.CreateField(ogr.FieldDefn("ctry_iso3", ogr.OFTString))
+        layer.CreateField(ogr.FieldDefn("owner_type", ogr.OFTString))
         layer.CreateField(ogr.FieldDefn("is_marine", ogr.OFTString))
         layer.CreateField(ogr.FieldDefn("type", ogr.OFTString))
         layer.CreateField(ogr.FieldDefn("iucn_cat", ogr.OFTString))
+        layer.CreateField(ogr.FieldDefn("status", ogr.OFTString))
+        layer.CreateField(ogr.FieldDefn("date", ogr.OFTString))
 
         # API
         category = "v3/protected_areas/search/"
@@ -110,10 +115,16 @@ def get_wdpa(iso3, output_dir="."):
                     feature.SetGeometry(g)
                     feature.SetField("wdpa_id", pa["wdpa_id"])
                     feature.SetField("pa_name", pa["name"])
+                    feature.SetField(
+                        "orig_name", pa["original_name"])
                     feature.SetField("ctry_iso3", iso3)
+                    feature.SetField("owner_type", pa["owner_type"])
                     feature.SetField("is_marine", str(pa["marine"]))
-                    feature.SetField("type", pa["designation"]["name"])
+                    feature.SetField(
+                        "type", pa["designation"]["name"])
                     feature.SetField("iucn_cat", pa["iucn_category"]["name"])
+                    feature.SetField("status", pa["legal_status"]["name"])
+                    feature.SetField("date", pa["legal_status_updated_at"])
                     # Add feature to layer
                     layer.CreateFeature(feature)
                     # Dereference the feature
