@@ -17,7 +17,6 @@ from pywdpa import get_wdpa
 # test_get_wdpa
 def test_get_wdpa():
     get_wdpa("MDG")
-    f = os.path.isfile("pa_MDG.shp")
-    assert f is True
+    assert os.path.isfile("pa_MDG.shp")
 
 # End
